# How to
If you have a [Framagit](https://framagit.org) account, you can fork and send merge requests.

The second favorite model is using [git send-email](https://git-scm.com/docs/git-send-email) to send patches.

At last, you can reupload this project to the git host of your choice and send the MR link with e-mail.

# Areas of interests
There are some important areas you can contribute to this project:

## Code
* Check bridges syntax based on bridge type.
* Move SaveButton click logic to actions.

## Community
* Improvement in Pypi release to support desktop-related issues better.
* Making native package build recepies for more GNU/Linux distros.
* Moving to GNOME Circle.

## Localization
translations are done on [Weblate](https://hosted.weblate.org/engage/carburetor).
